@@ -1,19 +1,29 @@
-/* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2010 - 2011 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2010 - 2012
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
 package org.puimula.libvoikko;
@@ -30,9 +40,7 @@ import org.puimula.libvoikko.Libvoikko.VoikkoHandle;
 
 import com.sun.jna.Native;
 import com.sun.jna.NativeLibrary;
-import com.sun.jna.NativeLong;
 import com.sun.jna.Pointer;
-import com.sun.jna.ptr.NativeLongByReference;
 import com.sun.jna.ptr.PointerByReference;
 
 /**
@@ -49,16 +57,30 @@ public class Voikko {
 
     private static Libvoikko library = null;
 
+    private static NativeLibrary tryLoadLibrary(String libName) {
+        try {
+            return NativeLibrary.getInstance(libName);
+        } catch (UnsatisfiedLinkError e) {
+            return null;
+        }
+    }
+
+    private static final String[] LIBRARY_NAMES = {
+        "libvoikko.so.1", // Use SONAME on Linux
+        "voikko-1", // On Windows major version of library API is part of the library name
+        "voikko" // Finally try to use platform dependent unversioned library
+    };
+
     private synchronized static Libvoikko getLib() {
         if (library == null) {
-            NativeLibrary nativeLibrary;
-            try {
-                nativeLibrary = NativeLibrary.getInstance("voikko");
-            } catch (UnsatisfiedLinkError e) {
-                // On Windows major version of library API is part of the library name
-                nativeLibrary = NativeLibrary.getInstance("voikko-1");  
+            for (String libName : LIBRARY_NAMES) {
+                NativeLibrary nativeLibrary = tryLoadLibrary(libName);
+                if (nativeLibrary != null) {
+                    library = (Libvoikko) Native.loadLibrary(nativeLibrary.getFile().getAbsolutePath(), Libvoikko.class);
+                    return library;
+                }
             }
-            library = (Libvoikko) Native.loadLibrary(nativeLibrary.getFile().getAbsolutePath(), Libvoikko.class);
+            throw new UnsatisfiedLinkError("Could not load the native component of libvoikko. Please see http://voikko.puimula.org/java.html for more information.");
         }
         return library;
     }
@@ -191,9 +213,10 @@ public class Voikko {
      * Unlike the C based API this method accepts multiple paragraphs
      * separated by newline characters.
      * @param text
+     * @param language language in which error descriptions should be returned
      * @return list of grammar errors
      */
-    public synchronized List<GrammarError> grammarErrors(String text) {
+    public synchronized List<GrammarError> grammarErrors(String text, String language) {
         requireValidHandle();
         List<GrammarError> errorList = new ArrayList<GrammarError>();
         if (!isValidInput(text)) {
@@ -201,29 +224,29 @@ public class Voikko {
         }
         int offset = 0;
         for (String paragraph : text.split("\\r?\\n")) {
-            appendErrorsFromParagraph(errorList, paragraph, offset);
+            appendErrorsFromParagraph(errorList, paragraph, offset, language);
             offset += paragraph.length() + 1;
         }
         return errorList;
     }
 
-    private void appendErrorsFromParagraph(List<GrammarError> errorList, String paragraph, int offset) {
+    private void appendErrorsFromParagraph(List<GrammarError> errorList, String paragraph, int offset, String language) {
         final int paragraphLen = s2n(paragraph).length - 1;
         final Libvoikko lib = getLib();
         int skipErrors = 0;
         while (true) {
             VoikkoGrammarError cError = lib.voikkoNextGrammarErrorCstr(handle,
-                    s2n(paragraph), new NativeLong(paragraphLen), new NativeLong(0), skipErrors);
+                    s2n(paragraph), new SizeT(paragraphLen), new SizeT(0), skipErrors);
             if (cError == null) {
                 return;
             }
-            errorList.add(getGrammarError(cError, offset));
+            errorList.add(getGrammarError(cError, offset, language));
             lib.voikkoFreeGrammarError(cError);
             skipErrors++;
         }
     }
 
-    private GrammarError getGrammarError(VoikkoGrammarError cError, int offset) {
+    private GrammarError getGrammarError(VoikkoGrammarError cError, int offset, String language) {
         final Libvoikko lib = getLib();
         int errorCode = lib.voikkoGetGrammarErrorCode(cError);
         int startPos = lib.voikkoGetGrammarErrorStartPos(cError).intValue();
@@ -239,16 +262,10 @@ public class Voikko {
                 suggestions.add(stringFromPointer(cStr));
             }
         }
-        return new GrammarError(errorCode, offset + startPos, errorLength, suggestions);
-    }
-
-    /**
-     * @param errorCode grammar error code
-     * @param language language in which the explanation should be returned
-     * @return a human readable explanation for grammar error
-     */
-    public String grammarErrorExplanation(int errorCode, String language) {
-        return getLib().voikko_error_message_cstr(errorCode, s2n(language)).toString();
+        Pointer cShortDescription = lib.voikkoGetGrammarErrorShortDescription(cError, s2n(language));
+        String shortDescription = stringFromPointer(cShortDescription);
+        lib.voikkoFreeErrorMessageCstr(cShortDescription);
+        return new GrammarError(errorCode, offset + startPos, errorLength, suggestions, shortDescription);
     }
 
     /**
@@ -310,9 +327,9 @@ public class Voikko {
         List<Token> result = new ArrayList<Token>();
         byte[] textBytes = s2n(text);
         int textLen = textBytes.length - 1;
-        NativeLongByReference tokenLenByRef = new NativeLongByReference();
+        SizeTByReference tokenLenByRef = new SizeTByReference();
         while (textLen > 0) {
-            int tokenTypeInt = lib.voikkoNextTokenCstr(handle, textBytes, new NativeLong(textLen), tokenLenByRef);
+            int tokenTypeInt = lib.voikkoNextTokenCstr(handle, textBytes, new SizeT(textLen), tokenLenByRef);
             int tokenLen = tokenLenByRef.getValue().intValue();
             TokenType tokenType = TokenType.values()[tokenTypeInt];
             String tokenText = text.substring(0, tokenLen);
@@ -339,9 +356,9 @@ public class Voikko {
         }
         byte[] textBytes = s2n(text);
         int textLen = textBytes.length - 1;
-        NativeLongByReference sentenceLenByRef = new NativeLongByReference();
+        SizeTByReference sentenceLenByRef = new SizeTByReference();
         while (textLen > 0) {
-            int sentenceTypeInt = lib.voikkoNextSentenceStartCstr(handle, textBytes, new NativeLong(textLen), sentenceLenByRef);
+            int sentenceTypeInt = lib.voikkoNextSentenceStartCstr(handle, textBytes, new SizeT(textLen), sentenceLenByRef);
             int sentenceLen = sentenceLenByRef.getValue().intValue();
             SentenceStartType sentenceType = SentenceStartType.values()[sentenceTypeInt];
             String tokenText = text.substring(0, sentenceLen);
@@ -367,7 +384,11 @@ public class Voikko {
         requireValidHandle();
         if (!isValidInput(word)) {
             // return string of spaces
-            return String.format("%1$#" + word.length() + "s", "");
+            StringBuilder sb = new StringBuilder();
+            for (int i = 0; i < word.length(); i++) {
+                sb.append(" ");
+            }
+            return sb.toString();
         }
         ByteArray cPattern = getLib().voikkoHyphenateCstr(handle, s2n(word));
         String pattern = cPattern.toString();
