@@ -20,22 +20,34 @@ An example session demonstrating the use of this module:
 
 """
 
-# Copyright 2009 - 2011 Harri Pitkänen (hatapitk@iki.fi)
-# This library requires Python version 2.5 or newer.
+# The contents of this file are subject to the Mozilla Public License Version 
+# 1.1 (the "License"); you may not use this file except in compliance with 
+# the License. You may obtain a copy of the License at 
+# http://www.mozilla.org/MPL/
+# 
+# Software distributed under the License is distributed on an "AS IS" basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+# for the specific language governing rights and limitations under the
+# License.
+# 
+# The Original Code is Libvoikko: Library of natural language processing tools.
+# The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+# Portions created by the Initial Developer are Copyright (C) 2009 - 2011
+# the Initial Developer. All Rights Reserved.
+# 
+# Alternatively, the contents of this file may be used under the terms of
+# either the GNU General Public License Version 2 or later (the "GPL"), or
+# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+# in which case the provisions of the GPL or the LGPL are applicable instead
+# of those above. If you wish to allow use of your version of this file only
+# under the terms of either the GPL or the LGPL, and not to allow others to
+# use your version of this file under the terms of the MPL, indicate your
+# decision by deleting the provisions above and replace them with the notice
+# and other provisions required by the GPL or the LGPL. If you do not delete
+# the provisions above, a recipient may use your version of this file under
+# the terms of any one of the MPL, the GPL or the LGPL.
 
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# This library requires Python version 2.5 or newer.
 
 from ctypes import byref
 from ctypes import CDLL
@@ -218,8 +230,8 @@ class Voikko(object):
 		self.__lib.voikkoFreeGrammarError.argtypes = [c_void_p]
 		self.__lib.voikkoFreeGrammarError.restype = None
 		
-		self.__lib.voikko_error_message_cstr.argtypes = [c_int, c_char_p]
-		self.__lib.voikko_error_message_cstr.restype = c_char_p
+		self.__lib.voikkoGetGrammarErrorShortDescription.argtypes = [c_void_p, c_char_p]
+		self.__lib.voikkoGetGrammarErrorShortDescription.restype = POINTER(c_char)
 		
 		self.__lib.voikkoHyphenateUcs4.argtypes = [c_void_p, c_wchar_p]
 		self.__lib.voikkoHyphenateUcs4.restype = POINTER(c_char)
@@ -230,6 +242,9 @@ class Voikko(object):
 		self.__lib.voikkoAnalyzeWordUcs4.argtypes = [c_void_p, c_wchar_p]
 		self.__lib.voikkoAnalyzeWordUcs4.restype = POINTER(c_void_p)
 		
+		self.__lib.voikkoFreeErrorMessageCstr.argtypes = [POINTER(c_char)]
+		self.__lib.voikkoFreeErrorMessageCstr.restype = None
+		
 		self.__lib.voikko_free_mor_analysis.argtypes = [POINTER(c_void_p)]
 		self.__lib.voikko_free_mor_analysis.restype = None
 		
@@ -385,7 +400,7 @@ class Voikko(object):
 		self.__lib.voikko_free_suggest_ucs4(cSuggestions)
 		return pSuggestions
 	
-	def __getGrammarError(self, cGrammarError):
+	def __getGrammarError(self, cGrammarError, language):
 		gError = GrammarError()
 		gError.errorCode = self.__lib.voikkoGetGrammarErrorCode(cGrammarError)
 		gError.startPos = self.__lib.voikkoGetGrammarErrorStartPos(cGrammarError)
@@ -397,9 +412,12 @@ class Voikko(object):
 			while bool(cSuggestions[i]):
 				gError.suggestions.append(unicode(cSuggestions[i], "UTF-8"))
 				i = i + 1
+		cErrorShortDescription = self.__lib.voikkoGetGrammarErrorShortDescription(cGrammarError, _anyStringToUtf8(language))
+		gError.shortDescription = unicode(string_at(cErrorShortDescription), "UTF-8")
+		self.__lib.voikkoFreeErrorMessageCstr(cErrorShortDescription)
 		return gError
 	
-	def __grammarParagraph(self, paragraph, offset):
+	def __grammarParagraph(self, paragraph, offset, language):
 		paragraphLen = len(paragraph)
 		skipErrors = 0
 		errorList = []
@@ -408,13 +426,13 @@ class Voikko(object):
 			        paragraph, paragraphLen, 0, skipErrors)
 			if not bool(cError):
 				return errorList
-			gError = self.__getGrammarError(cError)
+			gError = self.__getGrammarError(cError, language)
 			gError.startPos = offset + gError.startPos
 			errorList.append(gError)
 			self.__lib.voikkoFreeGrammarError(cError)
 			skipErrors = skipErrors + 1
 	
-	def grammarErrors(self, text):
+	def grammarErrors(self, text, language):
 		"""Check the given text for grammar errors and return a
 		list of GrammarError objects representing the errors that were found.
 		Unlike the C based API this method accepts multiple paragraphs
@@ -427,7 +445,7 @@ class Voikko(object):
 		errorList = []
 		offset = 0
 		for paragraph in textUnicode.split(u"\n"):
-			errorList = errorList + self.__grammarParagraph(paragraph, offset)
+			errorList = errorList + self.__grammarParagraph(paragraph, offset, language)
 			offset = offset + len(paragraph) + 1
 		return errorList
 	
