@@ -1,5 +1,5 @@
 /* Libvoikko: Library of Finnish language tools
- * Copyright (C) 2009 - 2010 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2009 - 2011 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,13 +73,19 @@ list<Analysis *> * MalagaAnalyzer::analyze(const char * word) {
 			parseBasicAttribute(analysis, res, symbols[MS_NEGATIVE], "NEGATIVE");
 			parseBasicAttribute(analysis, res, symbols[MS_POSSIBLE_GEOGRAPHICAL_NAME], "POSSIBLE_GEOGRAPHICAL_NAME");
 			parseBasicAttribute(analysis, res, symbols[MS_REQUIRE_FOLLOWING_VERB], "REQUIRE_FOLLOWING_VERB");
+			parseBasicAttribute(analysis, res, symbols[MS_TENSE], "TENSE");
+			parseBasicAttribute(analysis, res, symbols[MS_PARTICIPLE], "PARTICIPLE");
+			parseBasicAttribute(analysis, res, symbols[MS_POSSESSIVE], "POSSESSIVE");
+			parseBasicAttribute(analysis, res, symbols[MS_KYSYMYSLIITE], "KYSYMYSLIITE");
+			parseBasicAttribute(analysis, res, symbols[MS_FOCUS], "FOCUS");
+			parseBasicAttribute(analysis, res, symbols[MS_COMPARISON], "COMPARISON");
 			parsePerusmuoto(analysis, res);
 			analysisList->push_back(analysis);
 			res = next_analysis_result(&malagaState);
 			++currentAnalysisCount;
 		}
 	}
-	catch (setup::DictionaryException e) {
+	catch (setup::DictionaryException & /*e*/) {
 		// Something went wrong during analysis, just return the
 		// (probably empty) analysis list.
 	}
@@ -94,13 +100,13 @@ symbol_t MalagaAnalyzer::findSymbol(const char * name) {
 	value_t symbolValue;
 	try {
 		symbolValue = parse_malaga_symbol(name, &malagaState);
-	} catch (setup::DictionaryException e) {
+	} catch (setup::DictionaryException & /*e*/) {
 		return 0;
 	}
 	symbol_t symbol;
 	try {
 		symbol = value_to_symbol(symbolValue);
-	} catch (setup::DictionaryException e) {
+	} catch (setup::DictionaryException & /*e*/) {
 		symbol = 0;
 	}
 	free(symbolValue);
@@ -150,6 +156,24 @@ void MalagaAnalyzer::initSymbols() {
 			case MS_REQUIRE_FOLLOWING_VERB:
 				symbolName = "vaatii_tapaluokan";
 				break;
+			case MS_TENSE:
+				symbolName = "aikamuoto";
+				break;
+			case MS_PARTICIPLE:
+				symbolName = "laatutapa";
+				break;
+			case MS_POSSESSIVE:
+				symbolName = "omistusliite";
+				break;
+			case MS_KYSYMYSLIITE:
+				symbolName = "kysymysliite";
+				break;
+			case MS_FOCUS:
+				symbolName = "fokus";
+				break;
+			case MS_COMPARISON:
+				symbolName = "vertailu";
+				break;
 		}
 		symbols[sym] = findSymbol(symbolName);
 	}
@@ -208,6 +232,29 @@ void MalagaAnalyzer::initSymbols() {
 	insertToSymbolMap(symbolMap, "yes", L"true");
 	insertToSymbolMap(symbolMap, "no", L"false");
 	insertToSymbolMap(symbolMap, "molemmat", L"both");
+	
+	insertToSymbolMap(symbolMap, "kest\xc3\xa4m\xc3\xa4", L"present_simple");
+	insertToSymbolMap(symbolMap, "kertoma", L"past_imperfective");
+	
+	insertToSymbolMap(symbolMap, "johdin_vA", L"present_active");
+	insertToSymbolMap(symbolMap, "johdin_tAvA", L"present_passive");
+	insertToSymbolMap(symbolMap, "johdin_nUt", L"past_active");
+	insertToSymbolMap(symbolMap, "johdin_ttU", L"past_passive");
+	insertToSymbolMap(symbolMap, "johdin_mA", L"agent");
+	insertToSymbolMap(symbolMap, "johdin_tOn", L"negation");
+	
+	insertToSymbolMap(symbolMap, "omistusliite_1s", L"1s");
+	insertToSymbolMap(symbolMap, "omistusliite_2s", L"2s");
+	insertToSymbolMap(symbolMap, "omistusliite_1p", L"1p");
+	insertToSymbolMap(symbolMap, "omistusliite_2p", L"2p");
+	insertToSymbolMap(symbolMap, "omistusliite_3", L"3");
+	
+	insertToSymbolMap(symbolMap, "kin", L"kin");
+	insertToSymbolMap(symbolMap, "kaan", L"kaan");
+	
+	insertToSymbolMap(symbolMap, "perusaste", L"positive");
+	insertToSymbolMap(symbolMap, "voittoaste", L"comparative");
+	insertToSymbolMap(symbolMap, "yliaste", L"superlative");
 }
 
 void MalagaAnalyzer::parseStructure(Analysis * &analysis, value_t &result) const {
@@ -230,7 +277,7 @@ void MalagaAnalyzer::parseBasicAttribute(Analysis * &analysis, value_t &result,
 	symbol_t valueSym;
 	try {
 		valueSym = value_to_symbol(value);
-	} catch (setup::DictionaryException e) {
+	} catch (setup::DictionaryException & /*e*/) {
 		return;
 	}
 	map<symbol_t, const wchar_t *>::const_iterator mapIterator = symbolMap.find(valueSym);
@@ -282,6 +329,12 @@ static void fixCapitalisation(wchar_t * baseForm, const wchar_t * structure) {
 			++structPos;
 			continue;
 		}
+		if (baseForm[basePos] == L'-' && structure[structPos] != L'-') {
+			// If we have a compound word with hyphen and leading part has different
+			// length in baseform (Uusi-Seelanti -> Uudessa-Seelannissa) then
+			// structure and baseForm might get misaligned.
+			return;
+		}
 		if (structure[structPos] == L'i' || structure[structPos] == L'j') {
 			baseForm[basePos] = SimpleChar::upper(baseForm[basePos]);
 		}
