@@ -1,32 +1,42 @@
-/* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2006 - 2009 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2006 - 2009
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
 #include "porting.h"
 #include "setup/setup.hpp"
-#include "setup/DictionaryLoader.hpp"
+#include "setup/DictionaryFactory.hpp"
 #ifdef HAVE_GETPWUID_R
 #include <pwd.h>
 #endif // HAVE_GETPWUID_R
 #include "morphology/AnalyzerFactory.hpp"
 #include "spellchecker/SpellerFactory.hpp"
+#include "grammar/GrammarCheckerFactory.hpp"
 #include "spellchecker/suggestion/SuggestionGeneratorFactory.hpp"
 #include "hyphenator/HyphenatorFactory.hpp"
-#include "grammar/cachesetup.hpp"
 #include <cstring>
 #include <sys/stat.h>
 #include <cstdlib>
@@ -47,11 +57,11 @@ using namespace setup;
 static int setGrammarOption(voikko_options_t * handle, int value, int * option) {
 		if (value && !(*option)) {
 			*option = 1;
-			gc_clear_cache(handle);
+			handle->grammarChecker->cache.clear();
 		}
 		else if (!value && (*option)) {
 			*option = 0;
-			gc_clear_cache(handle);
+			handle->grammarChecker->cache.clear();
 		}
 		return 1;
 }
@@ -172,6 +182,7 @@ VOIKKOEXPORT voikko_options_t * voikkoInit(const char ** error, const char * lan
 	options->accept_unfinished_paragraphs_in_gc = 0;
 	options->accept_bulleted_lists_in_gc = 0;
 	options->morAnalyzer = 0;
+	options->grammarChecker = 0;
 	options->speller = 0;
 	options->suggestionGenerator = 0;
 	options->hyphenator = 0;
@@ -182,10 +193,10 @@ VOIKKOEXPORT voikko_options_t * voikkoInit(const char ** error, const char * lan
 		options->speller = 0;
 		Dictionary dict;
 		if (path) {
-			dict = DictionaryLoader::load(string(langcode), string(path));
+			dict = DictionaryFactory::load(string(langcode), string(path));
 		}
 		else {
-			dict = DictionaryLoader::load(string(langcode));
+			dict = DictionaryFactory::load(string(langcode));
 		}
 		options->dictionary = dict;
 		options->morAnalyzer = morphology::AnalyzerFactory::getAnalyzer(dict);
@@ -194,6 +205,7 @@ VOIKKOEXPORT voikko_options_t * voikkoInit(const char ** error, const char * lan
 			spellchecker::suggestion::SuggestionGeneratorFactory::getSuggestionGenerator(options,
 				spellchecker::suggestion::SUGGESTION_TYPE_STD);
 		options->hyphenator = hyphenator::HyphenatorFactory::getHyphenator(options, dict);
+		options->grammarChecker = grammar::GrammarCheckerFactory::getGrammarChecker(options, dict);
 	}
 	catch (DictionaryException & e) {
 		if (options->hyphenator) {
@@ -224,6 +236,7 @@ VOIKKOEXPORT voikko_options_t * voikkoInit(const char ** error, const char * lan
 }
 
 VOIKKOEXPORT void voikkoTerminate(voikko_options_t * handle) {
+	delete handle->grammarChecker;
 	handle->hyphenator->terminate();
 	delete handle->hyphenator;
 	delete handle->suggestionGenerator;
@@ -232,7 +245,6 @@ VOIKKOEXPORT void voikkoTerminate(voikko_options_t * handle) {
 	handle->morAnalyzer->terminate();
 	delete handle->morAnalyzer;
 	delete handle->spellerCache;
-	gc_clear_cache(handle);
 	delete handle;
 }
 
