@@ -1,5 +1,5 @@
 /* Libvoikko: Library of Finnish language tools
- * Copyright (C) 2009 - 2010 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2009 - 2013 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,39 +32,23 @@ using hfst_ol::ZHfstOspeller;
 
 namespace libvoikko { namespace spellchecker {
 
-
-HfstSpeller::HfstSpeller(const string & directoryName, voikko_options_t* opts)
-throw(setup::DictionaryException) {
-	speller_ = 0;
-	if ((opts != 0) && (opts->hfst != 0)) {
-		speller_ = opts->hfst;
+HfstSpeller::HfstSpeller(const string & zhfstFileName) throw(setup::DictionaryException) {
+	speller = new ZHfstOspeller();
+	try {
+		speller->read_zhfst(zhfstFileName.c_str());
 	}
-	else {
-		string spellerFile = directoryName + "/speller.zhfst";
-		speller_ = new ZHfstOspeller();
-		try {
-			speller_->read_zhfst(spellerFile.c_str());
-		}
-		catch (hfst_ol::ZHfstZipReadingError& zhzre) {
-			speller_->read_legacy(directoryName.c_str());
-		}
-		catch (hfst_ol::ZHfstLegacyReadingError& zhlre) {
-			throw setup::DictionaryException("no usable hfst spellers");
-		}
-		catch (hfst_ol::AlphabetTranslationException& ate) {
-			throw setup::DictionaryException("broken error model detected");
-		}
+	catch (hfst_ol::ZHfstZipReadingError& zhzre) {
+		throw setup::DictionaryException("Error reading ZHFST speller");
 	}
-	if (opts != 0)
-		opts->hfst = speller_;
 }
 
 spellresult HfstSpeller::doSpell(const wchar_t * word, size_t wlen) {
 	char * wordUtf8 = StringUtils::utf8FromUcs4(word, wlen);
 	spellresult result = SPELL_FAILED;
-	if (speller_->spell(wordUtf8)) {
+	if (speller->spell(wordUtf8)) {
 		result = SPELL_OK;
 	}
+	delete[] wordUtf8;
 	return result;
 }
  
@@ -84,9 +68,9 @@ spellresult HfstSpeller::spell(const wchar_t * word, size_t wlen) {
 }
 
 void HfstSpeller::terminate() {
-	if (speller_ != 0){
-		delete speller_;
-		speller_ = 0;
+	if (speller != 0) {
+		delete speller;
+		speller = 0;
 	}
 }
 
