@@ -1,19 +1,29 @@
-/* Voikkospell: Testing tool for libvoikko
- * Copyright (C) 2006 - 2010 Harri Pitkänen <hatapitk@iki.fi>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+/* The contents of this file are subject to the Mozilla Public License Version 
+ * 1.1 (the "License"); you may not use this file except in compliance with 
+ * the License. You may obtain a copy of the License at 
+ * http://www.mozilla.org/MPL/
+ * 
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ * 
+ * The Original Code is Libvoikko: Library of natural language processing tools.
+ * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
+ * Portions created by the Initial Developer are Copyright (C) 2006 - 2010
+ * the Initial Developer. All Rights Reserved.
+ * 
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
  *********************************************************************************/
 
 #include "../voikko.h"
@@ -36,7 +46,7 @@
 using namespace std;
 
 
-enum CheckMode {NORMAL, ONLY_C_W, ONLY_INCORRECT};
+enum CheckMode {NORMAL, ONLY_C_W, ONLY_INCORRECT, NONE};
 
 static const int MAX_WORD_LENGTH = 5000;
 static const int MAX_THREADS = 200;
@@ -75,7 +85,7 @@ static void printMorphology(VoikkoHandle * handle, const wchar_t * word, wstring
 }
 
 static void check_word(VoikkoHandle * handle, const wchar_t * word, wstringstream & out) {
-	int result = voikkoSpellUcs4(handle, word);
+	int result = (checkMode != NONE ? voikkoSpellUcs4(handle, word) : VOIKKO_SPELL_OK);
 	if (result == VOIKKO_CHARSET_CONVERSION_FAILED) {
 		cerr << "E: charset conversion failed" << endl;
 		return;
@@ -121,6 +131,8 @@ static void check_word(VoikkoHandle * handle, const wchar_t * word, wstringstrea
 					out << word << endl;
 				}
 				break;
+			case NONE:
+				break;
 		}
 	}
 	
@@ -266,6 +278,46 @@ static int list_dicts(const char * path) {
 	return 0;
 }
 
+static void printAndDeleteCapabilityList(const char * capability, char ** languageCodes) {
+	for (char ** i = languageCodes; *i; i++) {
+		cout << capability;
+		cout << ":";
+		cout << *i;
+		cout << endl;
+	}
+	voikkoFreeCstrArray(languageCodes);
+}
+
+/**
+ * Print a list of available dictionary capabilities to stdout.
+ * @return status code to be returned when the program exits.
+ */
+static int list_capabilities(const char * path) {
+	char ** languageCodes = voikkoListSupportedSpellingLanguages(path);
+	if (!languageCodes) {
+		cerr << "E: Failed to list dictionaries with spell checking capability" << endl;
+		return 1;
+	}
+	printAndDeleteCapabilityList("spell", languageCodes);
+	
+	languageCodes = voikkoListSupportedHyphenationLanguages(path);
+	if (!languageCodes) {
+		cerr << "E: Failed to list dictionaries with hyphenation capability" << endl;
+		return 1;
+	}
+	printAndDeleteCapabilityList("hyphen", languageCodes);
+	
+	languageCodes = voikkoListSupportedGrammarCheckingLanguages(path);
+	if (!languageCodes) {
+		cerr << "E: Failed to list dictionaries with grammar checking capability" << endl;
+		return 1;
+	}
+	printAndDeleteCapabilityList("grammar", languageCodes);
+	
+	return 0;
+}
+
+
 static void printHelp() {
 	cout << "Usage: voikkospell [OPTION]..." << endl;
 	cout << "Check spelling of words read from stdin." << endl;
@@ -290,6 +342,7 @@ int main(int argc, char ** argv) {
 	
 	cache_size = 0;
 	bool list_dicts_requested = false;
+	bool list_capabilities_requested = false;
 	for (int i = 1; i < argc; i++) {
 		string args(argv[i]);
 		if (args.find("-c") == 0) {
@@ -312,6 +365,9 @@ int main(int argc, char ** argv) {
 		else if (args == "-l") {
 			list_dicts_requested = true;
 		}
+		else if (args == "-L") {
+			list_capabilities_requested = true;
+		}
 		else if (args == "-j") {
 			#ifdef HAVE_PTHREAD
 				if (i + 1 == argc) {
@@ -334,6 +390,10 @@ int main(int argc, char ** argv) {
 		return list_dicts(path);
 	}
 	
+	if (list_capabilities_requested) {
+		return list_capabilities(path);
+	}
+	
 	spellers = new speller_t[threadCount];
 	for (int i = 0; i < threadCount; i++) {
 		const char * voikkoError;
@@ -369,6 +429,10 @@ int main(int argc, char ** argv) {
 			setBooleanOption(VOIKKO_OPT_ACCEPT_FIRST_UPPERCASE, 1);
 		else if (args == "accept_first_uppercase=0")
 			setBooleanOption(VOIKKO_OPT_ACCEPT_FIRST_UPPERCASE, 0);
+		else if (args == "accept_all_uppercase=1")
+			setBooleanOption(VOIKKO_OPT_ACCEPT_ALL_UPPERCASE, 1);
+		else if (args == "accept_all_uppercase=0")
+			setBooleanOption(VOIKKO_OPT_ACCEPT_ALL_UPPERCASE, 0);
 		else if (args == "accept_extra_hyphens=1")
 			setBooleanOption(VOIKKO_OPT_ACCEPT_EXTRA_HYPHENS, 1);
 		else if (args == "accept_extra_hyphens=0")
@@ -394,6 +458,10 @@ int main(int argc, char ** argv) {
 		else if (args == "-m") {
 			morphology = true;
 		}
+		else if (args == "-M") {
+			morphology = true;
+			checkMode = NONE;
+		}
 		else if (args.find("-c") == 0) {
 			continue;
 		}
